<?php

namespace Litecms\Representatives\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Representatives\Models\Representatives;

class RepresentativesPolicy
{

    /**
     * Determine if the given user can view the representatives.
     *
     * @param UserPolicy $user
     * @param Representatives $representatives
     *
     * @return bool
     */
    public function view(UserPolicy $user, Representatives $representatives)
    {
        if ($user->canDo('representatives.representatives.view') && $user->isAdmin()) {
            return true;
        }

        return $representatives->user_id == user_id() && $representatives->user_type == user_type();
    }

    /**
     * Determine if the given user can create a representatives.
     *
     * @param UserPolicy $user
     * @param Representatives $representatives
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('representatives.representatives.create');
    }

    /**
     * Determine if the given user can update the given representatives.
     *
     * @param UserPolicy $user
     * @param Representatives $representatives
     *
     * @return bool
     */
    public function update(UserPolicy $user, Representatives $representatives)
    {
        if ($user->canDo('representatives.representatives.edit') && $user->isAdmin()) {
            return true;
        }

        return $representatives->user_id == user_id() && $representatives->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given representatives.
     *
     * @param UserPolicy $user
     * @param Representatives $representatives
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Representatives $representatives)
    {
        return $representatives->user_id == user_id() && $representatives->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given representatives.
     *
     * @param UserPolicy $user
     * @param Representatives $representatives
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Representatives $representatives)
    {
        if ($user->canDo('representatives.representatives.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given representatives.
     *
     * @param UserPolicy $user
     * @param Representatives $representatives
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Representatives $representatives)
    {
        if ($user->canDo('representatives.representatives.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
